.. _version_history:

===============
Version History
===============

Origins
=======

**twined** began as an internal tool at Octue, enabling applications to be connected together in the Octue ecosystem.

The twined library is presently being ported out of Octue's SDKs as it became clear that it would be most beneficial to
open-source the framework we developed to connect applications and digital twins together.


.. _version_0.0.1:
0.0.1
======

Initial library framework - development version. Highly unstable! Let's see what happens...

New Features
------------
#. Documentation
#. Travis- and RTD- based test and documentation build with Codecov integration

Backward Incompatible API Changes
---------------------------------
#. n/a (Initial release)

Bug Fixes & Minor Changes
-------------------------
#. n/a (Initial Release)

